# In brevi

**bricoleur** is a Python library for 'bricoleurs' who engage is the art of 'bricolage.'

Why **bricoleur**?

- Equivalent Python functions that are available online and in construction calculators.
- Develop a free open source package.

# Documentation

Full documentation is available at [https://bricoleur.readthedocs.io/en/latest/](https://bricoleur.readthedocs.io/en/latest/).

# References

To cite this repository, please use:

@software{bricoleur,
  author  = {Gilles Pilon},
  title   = {bricoleur},
  url     = {https://github.com/gillespilon/bricoleur},
  version = {0.0.2},
  date    = {2025-04-01}
}
